# Windows Packaged Release

To install the Windows Packaged Release plaso you need to download the latest version from https://github.com/log2timeline/plaso/releases

Attached to the most recent release (as of this time version 20170930) is a ZIP file.

The name of the ZIP file contains:

* amd64 which indicates the architecture of the binaries in the ZIP.
* vs2008 or vs2010 which indicates the Visual Studio version used to build the binaries. You'll need to have the corresponding Visual C++ Redistributable package installed, which you can obtain from [Microsoft Download Center](https://www.microsoft.com/en-us/search/Results.aspx?q=Microsoft%20Visual%20C%2B%2B%20Redistributable%20Package&form=DLC).

Extract the ZIP file and you're ready to log2timeline.
